@@ -1,18 +1,19 @@
-from typing import Any
-from typing import Dict
+from __future__ import annotations
 
-from .config_source import ConfigSource
+from typing import Any
+
+from poetry.config.config_source import ConfigSource
 
 
 class DictConfigSource(ConfigSource):
-    def __init__(self):  # type: () -> None
-        self._config = {}
+    def __init__(self) -> None:
+        self._config: dict[str, Any] = {}
 
     @property
-    def config(self):  # type: () -> Dict[str, Any]
+    def config(self) -> dict[str, Any]:
         return self._config
 
-    def add_property(self, key, value):  # type: (str, Any) -> None
+    def add_property(self, key: str, value: Any) -> None:
         keys = key.split(".")
         config = self._config
 
@@ -26,7 +27,7 @@ class DictConfigSource(ConfigSource):
 
             config = config[key]
 
-    def remove_property(self, key):  # type: (str) -> None
+    def remove_property(self, key: str) -> None:
         keys = key.split(".")
 
         config = self._config
