@@ -10,7 +10,7 @@ if TYPE_CHECKING:
     from poetry.puzzle.exceptions import SolverProblemError
 
 
-class PythonRequirementSolution(Solution):  # type: ignore[misc]
+class PythonRequirementSolution(Solution):
     def __init__(self, exception: SolverProblemError) -> None:
         from poetry.core.constraints.version import parse_constraint
 
@@ -58,6 +58,6 @@ class PythonRequirementSolution(Solution):  # type: ignore[misc]
     @property
     def documentation_links(self) -> list[str]:
         return [
-            "https://python-poetry.org/docs/dependency-specification/#python-restricted-dependencies",  # noqa: E501
-            "https://python-poetry.org/docs/dependency-specification/#using-environment-markers",  # noqa: E501
+            "https://python-poetry.org/docs/dependency-specification/#python-restricted-dependencies",
+            "https://python-poetry.org/docs/dependency-specification/#using-environment-markers",
         ]
